@@ -1,8 +1,5 @@
-# builtin modules
-import sys
-
 # pyqt modules
-from PyQt4.QtGui import (QApplication, QDialog, QStandardItem,  QStandardItemModel)
+from PyQt4.QtGui import (QDialog, QStandardItem,  QStandardItemModel)
 from PyQt4.QtCore import (pyqtSignature, Qt, SIGNAL)
 from PyQt4.QtMaemo5 import (QMaemo5ListPickSelector, QMaemo5ValueButton)
 
@@ -10,12 +7,12 @@ from PyQt4.QtMaemo5 import (QMaemo5ListPickSelector, QMaemo5ValueButton)
 import config as c
 
 # program modules 
-from ui_settings_dialog import Ui_SettingsDialog
+from ui.ui_settings_dialog import Ui_SettingsDialog
 
 class SettingsDialog(QDialog, Ui_SettingsDialog):
 
     def __init__(self, parent=None):
-        super(QDialog, self).__init__(parent)
+        super(SettingsDialog, self).__init__(parent)
         self.config = c.Config()
 
         self.setupUi(self)
