@@ -12,9 +12,9 @@ import config as c
 
 # program modules 
 from database import Database
-from ui_welcome_window import Ui_WelcomeWindow
+from ui.ui_welcome_window import Ui_WelcomeWindow
 import exercises_window as ew
-import workouts_window as ww
+import routines_window as ww
 import target_areas_window as taw
 import meals_window as mw
 import settings_dialog as sd
@@ -51,8 +51,8 @@ class WelcomeWindow(QMainWindow, Ui_WelcomeWindow):
         if self.config.interface['remember-last-fitness']:
             if self.config.interface['last-fitness'] == 'exercises':
                 self.fitness_window = ew.ExercisesWindow(self, self.db)
-            elif self.config.interface['last-fitness'] == 'workouts':
-                self.fitness_window = ww.WorkoutsWindow(self, self.db)
+            elif self.config.interface['last-fitness'] == 'routines':
+                self.fitness_window = ww.RoutinesWindow(self, self.db)
             elif self.config.interface['last-fitness'] == 'target_areas':
                 self.fitness_window = taw.TargetAreasWindow(self, self.db)
         else:
